package com.energy.manage.service.service.windenginegroup.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.excel.EasyExcel;
import com.energy.manage.common.base.BaseServiceImpl;
import com.energy.manage.common.base.Page;
import com.energy.manage.common.constant.Constants;
import com.energy.manage.common.constant.redis.ManagerRedisKeyConstant;
import com.energy.manage.common.enums.DeleteStatusEnum;
import com.energy.manage.common.enums.IdPrefixEnum;
import com.energy.manage.common.po.windenginegroup.WindEngineGroupPO;
import com.energy.manage.common.po.windenginemill.WindEngineMillPO;
import com.energy.manage.common.po.windfield.WindFieldPO;
import com.energy.manage.common.util.IdGeneratorUtil;
import com.energy.manage.service.domain.dto.windenginegroup.WindEngineGroupCodeDto;
import com.energy.manage.service.domain.dto.windenginegroup.WindEngineGroupCreateDto;
import com.energy.manage.service.domain.dto.windenginegroup.WindEngineGroupPageDto;
import com.energy.manage.service.domain.dto.windenginegroup.WindEngineGroupStateDto;
import com.energy.manage.service.domain.dto.windfield.WindFieldImportDataDto;
import com.energy.manage.service.domain.vo.excel.WindEngineGroupExcelVo;
import com.energy.manage.service.domain.vo.excel.WindFieldExceVo;
import com.energy.manage.service.domain.vo.windenginegroup.WindEngineGroupPageVo;
import com.energy.manage.service.domain.vo.windenginegroup.WindEngineGroupVo;
import com.energy.manage.service.domain.vo.windenginemill.WindEngineMillPageVo;
import com.energy.manage.service.domain.vo.windfield.WindFieldPageVo;
import com.energy.manage.service.mappers.windenginegroup.WindEngineGroupMapper;
import com.energy.manage.service.service.cache.CacheService;
import com.energy.manage.service.service.windenginegroup.WindEngineGroupService;
import com.energy.manage.service.service.windfield.WindFieldService;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Lists;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.web.multipart.MultipartFile;
import tk.mybatis.mapper.entity.Example;

import java.util.Date;
import java.util.List;


@Slf4j
@Service
public class WindEngineGroupServiceImpl extends BaseServiceImpl<WindEngineGroupPO> implements WindEngineGroupService {


        @Autowired
        private CacheService cacheService;


        @Autowired
        private WindEngineGroupMapper windEngineGroupMapper;

        @Autowired
        private WindFieldService windFieldService;

        /**
         * 手动创建风机机组信息
         *
         * @param windEngineGroupCreateDto
         * @return
         */
        @Override
        @Transactional(rollbackFor = Exception.class)
        public boolean createWindEngineGroup(WindEngineGroupCreateDto windEngineGroupCreateDto) {
        WindEngineGroupPO windEngineGroupPO = new WindEngineGroupPO();
        BeanUtil.copyProperties(windEngineGroupCreateDto, windEngineGroupPO);
        String number = IdPrefixEnum.WIND_GROUP_NUMBER.getCode().concat(IdGeneratorUtil.zeroFillUtil(cacheService.incr(ManagerRedisKeyConstant.build(ManagerRedisKeyConstant.IDGENERATOR_CONSTANTS_KEY, IdPrefixEnum.WIND_GROUP_NUMBER.getCode()))));
        windEngineGroupPO.setEngineCode(number);
        windEngineGroupPO.setCreateTime(new Date());
        windEngineGroupPO.setUpdateTime(new Date());
        windEngineGroupPO.setState(Constants.GLOBAL_IN_USE);
        windEngineGroupPO.setDelState(DeleteStatusEnum.NODELETE.getCode());





        return windEngineGroupMapper.insertUseGeneratedKeys(windEngineGroupPO) > 0;
    }


    @SneakyThrows
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean windEngineGroupImportData(MultipartFile file, String fieldCode) {
        List<WindEngineGroupExcelVo> windEngineGroupExcelVos = EasyExcel.read(file.getInputStream()).head(WindFieldExceVo.class).sheet().doReadSync();
        if (CollectionUtils.isEmpty(windEngineGroupExcelVos)) {
            return false;
        }
        WindEngineGroupPO windEngineGroupPO = null;
        List<WindEngineGroupPO> list = Lists.newArrayList();

        for (WindEngineGroupExcelVo windFieldExceVos : windEngineGroupExcelVos) {
            windEngineGroupPO = this.createWindEngineGroupPO(fieldCode);
            BeanUtil.copyProperties(windFieldExceVos, windEngineGroupPO);
            list.add(windEngineGroupPO);
        }
        if (CollectionUtils.isEmpty(list)) {
            return false;
        }
        return windEngineGroupMapper.insertList(list) > 0;
    }

    @Override
    public boolean afreshWindEngineGroupImportData(MultipartFile file, String fieldCode) {
        // 删除企业下所有风场
        if (!delFieldWindEngineGroup(fieldCode)) {
            return false;
        }
        return windEngineGroupImportData(file, fieldCode);
    }

    /**
     * 创建对象
     *
     * @param fieldCode
     * @return
     */
    private WindEngineGroupPO createWindEngineGroupPO(String fieldCode) {
        WindEngineGroupPO windEngineGroupPO = new WindEngineGroupPO();
        String number = IdPrefixEnum.WIND_GROUP_NUMBER.getCode().concat(IdGeneratorUtil.zeroFillUtil(cacheService.incr(ManagerRedisKeyConstant.build(ManagerRedisKeyConstant.IDGENERATOR_CONSTANTS_KEY, IdPrefixEnum.WIND_GROUP_NUMBER.getCode()))));
        windEngineGroupPO.setEngineCode(number);
        windEngineGroupPO.setFieldCode(fieldCode);
        windEngineGroupPO.setCreateTime(new Date());
        windEngineGroupPO.setUpdateTime(new Date());
        windEngineGroupPO.setState(Constants.GLOBAL_IN_USE);
        windEngineGroupPO.setDelState(DeleteStatusEnum.NODELETE.getCode());
        return windEngineGroupPO;
    }


    @Override
    public Page<WindEngineGroupPageVo> windEngineGrouPage(WindEngineGroupPageDto windEngineGroupPageDto) {
        PageHelper.startPage(windEngineGroupPageDto.getPageNum(), windEngineGroupPageDto.getPageSize());
        List<WindEngineGroupPageVo> list = windEngineGroupMapper.selectWindEngineGroupByNames(windEngineGroupPageDto);
        Long total = org.apache.commons.collections.CollectionUtils.isEmpty(list) ? 0L : new PageInfo<>(list).getTotal();
        return Page.build(windEngineGroupPageDto.getPageNum(), windEngineGroupPageDto.getPageSize(), total, list);
    }

    @Override
    public boolean delFieldWindEngineGroup(String fieldCode) {

        WindEngineGroupPO po = new WindEngineGroupPO();
        po.setDelState(DeleteStatusEnum.DELETE.getCode());
        Example queryExample = new Example(WindEngineMillPO.class);
        Example.Criteria criteria = queryExample.createCriteria();
        criteria.andEqualTo("fieldCode", fieldCode);

        return windEngineGroupMapper.updateByExampleSelective(po, queryExample) > 0;
    }

    @Override
    public boolean delWindEngineGroup(WindEngineGroupCodeDto windEngineGroupCodeDto) {

        WindEngineGroupPO windEngineGroupPO = new WindEngineGroupPO();
        windEngineGroupMapper.selectOne(windEngineGroupPO);

        WindEngineGroupPO po = new WindEngineGroupPO();
        po.setDelState(DeleteStatusEnum.DELETE.getCode());
        Example queryExample = new Example(WindEngineGroupPO.class);
        Example.Criteria criteria = queryExample.createCriteria();
        criteria.andEqualTo("engineCode", windEngineGroupCodeDto.getEngineCode());

        // 删除风机
        if (windEngineGroupMapper.updateByExampleSelective(po, queryExample) <= 0) {
            return false;
        }

        // 更新风场下风机数量
        return windFieldService.updateWindFieldNumber(windEngineGroupPO.getFieldCode());
    }

    @Override
    public boolean updateStateWindEngineGroup(WindEngineGroupStateDto windEngineGroupStateDto) {
        WindEngineGroupPO po = new WindEngineGroupPO();
        po.setState(windEngineGroupStateDto.getState());
        Example queryExample = new Example(WindEngineGroupPO.class);
        Example.Criteria criteria = queryExample.createCriteria();
        criteria.andEqualTo("engineCode", windEngineGroupStateDto.getEngineCode());
        return windEngineGroupMapper.updateByExampleSelective(po, queryExample) > 0;
    }

    @Override
    public WindEngineGroupVo getWindEngineGroup(WindEngineGroupCodeDto windEngineGroupCodeDto) {
        WindEngineGroupPO po = new WindEngineGroupPO();
        po.setEngineCode(windEngineGroupCodeDto.getEngineCode());
        WindEngineGroupPO windEngineGroupPO = windEngineGroupMapper.selectOne(po);
        if (windEngineGroupPO == null) {
            return null;
        }
        WindEngineGroupVo windEngineGroupVo = new WindEngineGroupVo();
        BeanUtil.copyProperties(windEngineGroupPO, windEngineGroupVo);
        return windEngineGroupVo;
    }
}
